from setuptools import setup

setup(
    name="VLoDVP",
    version="1.0.5",
    description="Validating Licenses on Discord Validating Package",
    author="tagoWorks",
    author_email="santiagobuisnessmail@gmail.com",
    install_requires=[
        'requests', 'cryptography'
    ]
)